cgen: An Abstract Syntax Tree for C, in Python
----------------------------------------------

.. image:: https://gitlab.tiker.net/inducer/cgen/badges/main/pipeline.svg
    :alt: Gitlab Build Status
    :target: https://gitlab.tiker.net/inducer/cgen/commits/main
.. image:: https://github.com/inducer/cgen/actions/workflows/ci.yml/badge.svg
    :alt: Github Build Status
    :target: https://github.com/inducer/cgen/actions/workflows/ci.yml
.. image:: https://badge.fury.io/py/cgen.svg
    :alt: Python Package Index Release Page
    :target: https://pypi.org/project/cgen/

cgen offers a simple abstract syntax tree for C and related languages
(C++/CUDA/OpenCL) to allow structured code generation from Python.
To represent mathematical expressions, cgen can be used with `pymbolic
<https://github.com/inducer/pymbolic>`__.

Places on the web related to cgen:

* `Python package index <https://pypi.org/project/cgen>`__ (download releases)
* `Documentation <https://documen.tician.de/cgen>`__ (read how things work)
* `Github <https://github.com/inducer/cgen>`__ (get latest source code, file bugs)

cgen is licensed under the liberal `MIT license
<https://en.wikipedia.org/wiki/MIT_License>`__ and free for commercial, academic,
and private use. All of cgen's dependencies can be automatically installed from
the package index after using::

    pip install cgen
